<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;


class PasswordReset extends Model {

    public $table = 'password_resets';
    public $primaryKey = 'email';

    protected $fillable = [
        'email',
        'token',
        'created_at'
    ];
}
